##########
As Package
##########

*****
Conda
*****

Currently ADIOS 2 can be obtained from anaconda cloud:

* x86-64 and MacOS: `williamfgc adios2-openmpi adios2-mpich adios2-nompi <https://anaconda.org/williamfgc>`_  
* Multiple archs: `conda-forge adios2 <https://anaconda.org/conda-forge/adios2>`_


*****
Spack
*****

ADIOS 2 is packaged in Spack `adios2 package <https://spack.readthedocs.io/en/latest/package_list.html#adios2>`_


******
Docker
******

Docker images including building and installation of dependencies and ADIOS 2 containers for Ubuntu 20 and CentOS 7 can be found in: 
under the directory `scripts/docker/ <https://github.com/ornladios/ADIOS2/tree/master/scripts/docker>`_
